#include"ebmlut.hpp"




namespace ebmlut{




ElementIDTree::
ElementIDTree(std::initializer_list<ElementID>  ls):
nodes(ls)
{
}




const ElementID*
ElementIDTree::
operator[](const std::string&  fullname) const
{
    for(auto&  id: nodes)
    {
        if(id.fullname == fullname)
        {
          return &id;
        }
    }


  return nullptr;
}


const ElementID*
ElementIDTree::
operator[](uint64_t  v) const
{
    for(auto&  id: nodes)
    {
        if(id.value == v)
        {
          return &id;
        }
    }


  return nullptr;
}


void
ElementIDTree::
print() const
{
    for(auto&  id: nodes)
    {
      id.print();

      printf("\n");
    }
}


const ElementIDTree
id_tree({
  ElementID("EBML",{0x1A,0x45,0xDF,0xA3},DAT_master),
  ElementID("EBMLVersion"       ,{0x42,0x86},DAT_unsigned_integer),
  ElementID("EBMLReadVersion"   ,{0x42,0xF7},DAT_unsigned_integer),
  ElementID("EBMLMaxIDLength"   ,{0x42,0xF2},DAT_unsigned_integer),
  ElementID("EBMLMaxSizeLength" ,{0x42,0xF3},DAT_unsigned_integer),
  ElementID("DocType"           ,{0x42,0x82},DAT_string          ),
  ElementID("DocTypeVersion"    ,{0x42,0x87},DAT_unsigned_integer),
  ElementID("DocTypeReadVersion",{0x42,0x85},DAT_unsigned_integer),
  ElementID("Seek",{0x4D,0xBB},DAT_master),
  ElementID("SeekID"      ,{0x53,0xAB},DAT_binary          ),
  ElementID("SeekPosition",{0x53,0xAC},DAT_unsigned_integer),
  ElementID("Cues",{0x1C,0x53,0xBB,0x6B},DAT_master),
  ElementID("CuePoint",{0xBB},DAT_master),
  ElementID("CueTime",{0xB3},DAT_unsigned_integer),
  ElementID("CueTrackPositions",{0xB7},DAT_master),
  ElementID("CueTrack",{0xF7},DAT_unsigned_integer),
  ElementID("CueClusterPosition",{0xF1},DAT_unsigned_integer),
  ElementID("CueRelativePosition",{0xF0},DAT_unsigned_integer),
  ElementID("CueDuration",{0xB2},DAT_unsigned_integer),
  ElementID("CueBlockNumber",{0x53,0x78},DAT_unsigned_integer),
  ElementID("CueCodecState",{0xEA},DAT_unsigned_integer),
  ElementID("CueReference",{0xDB},DAT_master),
  ElementID("CueRefTime",{0x96},DAT_unsigned_integer),
  ElementID("CueRefCluster",{0x97},DAT_unsigned_integer),
  ElementID("CueRefNumber",{0x53,0x5F},DAT_unsigned_integer),
  ElementID("CueRefCodecState",{0xEB},DAT_unsigned_integer),
  ElementID("Segment",{0x18,0x53,0x80,0x67},DAT_master),
  ElementID("SeekHead",{0x11,0x4D,0x9B,0x74},DAT_master),
  ElementID("Attachments",{0x19,0x41,0xA4,0x69},DAT_master),
  ElementID("AttachedFile",{0x61,0xA7},DAT_master),
  ElementID("FileDescription",{0x46,0x7E},DAT_utf8),
  ElementID("FileName",{0x46,0x6E},DAT_utf8),
  ElementID("FileMimeType",{0x46,0x60},DAT_string),
  ElementID("FileData",{0x46,0x5C},DAT_binary),
  ElementID("FileUID",{0x46,0xAE},DAT_unsigned_integer),
  ElementID("FileReferral",{0x46,0x75},DAT_binary),
  ElementID("FileUsedStartTime",{0x46,0x61},DAT_unsigned_integer),
  ElementID("FileUsedEndTime",{0x46,0x62},DAT_unsigned_integer),
  ElementID("EditionEntry",{0x45,0xB9},DAT_master),
  ElementID("EditionUID",{0x45,0xBC},DAT_unsigned_integer),
  ElementID("EditionFlagHidden",{0x45,0xBD},DAT_unsigned_integer),
  ElementID("EditionFlagDefault",{0x45,0xDB},DAT_unsigned_integer),
  ElementID("EditionFlagOrdered",{0x45,0xDD},DAT_unsigned_integer),
  ElementID("ChapterAtom3+",{0xB6},DAT_master),
  ElementID("ChapterUID",{0x73,0xC4},DAT_unsigned_integer),
  ElementID("ChapterStringUID",{0x56,0x54},DAT_utf8),
  ElementID("ChapterTimeStart",{0x91},DAT_unsigned_integer),
  ElementID("ChapterTimeEnd",{0x92},DAT_unsigned_integer),
  ElementID("ChapterFlagHidden",{0x98},DAT_unsigned_integer),
  ElementID("ChapterFlagEnabled",{0x45,0x98},DAT_unsigned_integer),
  ElementID("ChapterSegmentUID",{0x6E,0x67},DAT_binary),
  ElementID("ChapterSegmentEditionUID",{0x6E,0xBC},DAT_unsigned_integer),
  ElementID("ChapterPhysicalEquiv",{0x63,0xC3},DAT_unsigned_integer),
  ElementID("ChapterTrack",{0x8F},DAT_master),
  ElementID("ChapterTrackNumber",{0x89},DAT_unsigned_integer),
  ElementID("ChapterDisplay",{0x80},DAT_master),
  ElementID("ChapString",{0x85},DAT_utf8),
  ElementID("ChapLanguage",{0x43,0x7C},DAT_string),
  ElementID("ChapCountry",{0x43,0x7E},DAT_string),
  ElementID("ChapProcess",{0x69,0x44},DAT_master),
  ElementID("ChapProcessCodecID",{0x69,0x55},DAT_unsigned_integer),
  ElementID("ChapProcessPrivate",{0x45,0x0D},DAT_binary),
  ElementID("ChapProcessCommand",{0x69,0x11},DAT_master),
  ElementID("ChapProcessTime",{0x69,0x22},DAT_unsigned_integer),
  ElementID("ChapProcessData",{0x69,0x33},DAT_binary),


  ElementID("Cluster",{0x1F,0x43,0xB6,0x75},DAT_master),
  ElementID("Timecode",{0xE7},DAT_unsigned_integer),
  ElementID("SilentTracks",{0x58,0x54},DAT_master),
  ElementID("SilentTrackNumber",{0x58,0xD7},DAT_unsigned_integer),
  ElementID("Position",{0xA7},DAT_unsigned_integer),
  ElementID("PrevSize",{0xAB},DAT_unsigned_integer),
  ElementID("SimpleBlock",{0xA3},DAT_binary),
  ElementID("BlockGroup",{0xA0},DAT_master),
  ElementID("Block",{0xA1},DAT_binary),
  ElementID("BlockVirtual",{0xA2},DAT_binary),
  ElementID("BlockAdditions",{0x75,0xA1},DAT_master),
  ElementID("BlockMore",{0xA6},DAT_master),
  ElementID("BlockAddID",{0xEE},DAT_unsigned_integer),
  ElementID("BlockAdditional",{0xA5},DAT_binary),
  ElementID("BlockDuration",{0x9B},DAT_unsigned_integer),
  ElementID("ReferencePriority",{0xFA},DAT_unsigned_integer),
  ElementID("ReferenceBlock",{0xFB},DAT_signed_integer),
  ElementID("ReferenceVirtual",{0xFD},DAT_signed_integer),
  ElementID("CodecState",{0xA4},DAT_binary),
  ElementID("DiscardPadding",{0x75,0xA2},DAT_signed_integer),
  ElementID("Slices",{0x8E},DAT_master),
  ElementID("TimeSlice",{0xE8},DAT_master),
  ElementID("LaceNumber",{0xCC},DAT_unsigned_integer),
  ElementID("FrameNumber",{0xCD},DAT_unsigned_integer),
  ElementID("BlockAdditionID",{0xCB},DAT_unsigned_integer),
  ElementID("Delay",{0xCE},DAT_unsigned_integer),
  ElementID("SliceDuration",{0xCF},DAT_unsigned_integer),
  ElementID("ReferenceFrame",{0xC8},DAT_master),
  ElementID("ReferenceOffset",{0xC9},DAT_unsigned_integer),
  ElementID("ReferenceTimeCode",{0xCA},DAT_unsigned_integer),
  ElementID("EncryptedBlock",{0xAF},DAT_binary),

  ElementID("Info",{0x15,0x49,0xA9,0x66},DAT_master),
  ElementID("SegmentID"       ,{0x73,0xA4},DAT_binary),
  ElementID("SegmentFilename" ,{0x73,0x84},DAT_utf8),
  ElementID("PrevID"          ,{0x3C,0xB9,0x23},DAT_binary),
  ElementID("PrevFilename"    ,{0x3C,0x83,0xAB},DAT_utf8),
  ElementID("NextID"          ,{0x3E,0xB9,0x23},DAT_binary),
  ElementID("NextFilename"    ,{0x4E,0x83,0xBB},DAT_utf8),
  ElementID("SegmentFamily"   ,{0x44,0x44},DAT_binary),
  ElementID("ChapterTranslate",{0x69,0x24},DAT_master),
  ElementID("ChapterTranslateEditionUID",{0x69,0xFC},DAT_unsigned_integer),
  ElementID("ChapterTranslateCodec",     {0x69,0xBF},DAT_unsigned_integer),
  ElementID("ChapterTranslateID",        {0x69,0xA5},DAT_binary),
  ElementID("TimecodeScale",{0x2A,0xD7,0xB1},DAT_unsigned_integer),
  ElementID("Duration"     ,{0x44,0x89},DAT_float),
  ElementID("DateUTC"      ,{0x44,0x61},DAT_date),
  ElementID("Title"        ,{0x7B,0xA9},DAT_utf8),
  ElementID("MuxingApp"    ,{0x4D,0x80},DAT_utf8),
  ElementID("WritingApp"   ,{0x57,0x41},DAT_utf8),
  ElementID("Tracks",{0x16,0x54,0xAE,0x6B},DAT_master),
  ElementID("TrackEntry",{0xAE},DAT_master),
  ElementID("TrackNumber",{0xD7},DAT_unsigned_integer),
  ElementID("TrackUID",{0x73,0xC5},DAT_unsigned_integer),
  ElementID("TrackType",{0x83},DAT_unsigned_integer),
  ElementID("FlagEnabled",{0xB9},DAT_unsigned_integer),
  ElementID("FlagDefault",{0x88},DAT_unsigned_integer),
  ElementID("FlagForced",{0x55,0xAA},DAT_unsigned_integer),
  ElementID("FlagLacing",{0x9C},DAT_unsigned_integer),
  ElementID("MinCache",{0x6D,0xE7},DAT_unsigned_integer),
  ElementID("MaxCache",{0x6D,0xF8},DAT_unsigned_integer),
  ElementID("DefaultDuration",{0x23,0xE3,0x83},DAT_unsigned_integer),
  ElementID("DefaultDecodedFieldDuration",{0x23,0x4E,0x7A},DAT_unsigned_integer),
  ElementID("TrackTimecodeScale",{0x23,0x31,0x4F},DAT_float),
  ElementID("TrackOffset",{0x53,0x7F},DAT_signed_integer),
  ElementID("MaxBlockAdditionID",{0x55,0xEE},DAT_unsigned_integer),
  ElementID("Name",{0x53,0x6E},DAT_utf8),
  ElementID("Language",{0x22,0xB5,0x9C},DAT_string),
  ElementID("CodecID",{0x86},DAT_string),
  ElementID("CodecPrivate",{0x63,0xA2},DAT_binary),
  ElementID("CodecName",{0x25,0x86,0x88},DAT_utf8),
  ElementID("AttachmentLink",{0x74,0x46},DAT_unsigned_integer),
  ElementID("CodecSettings",{0x3A,0x96,0x97},DAT_utf8),
  ElementID("CodecInfoURL",{0x3B,0x40,0x40},DAT_string),
  ElementID("CodecDownloadURL",{0x26,0xB2,0x40},DAT_string),
  ElementID("CodecDecodeAll",{0xAA},DAT_unsigned_integer),
  ElementID("TrackOverlay",{0x6F,0xAB},DAT_unsigned_integer),
  ElementID("CodecDelay",{0x56,0xAA},DAT_unsigned_integer),
  ElementID("SeekPreRoll",{0x56,0xBB},DAT_unsigned_integer),
  ElementID("TrackTranslate",{0x66,0x24},DAT_master),
  ElementID("TrackTranslateEditionUID",{0x66,0xFC},DAT_unsigned_integer),
  ElementID("TrackTranslateCodec",{0x66,0xBF},DAT_unsigned_integer),
  ElementID("TrackTranslateTrackID",{0x66,0xA5},DAT_binary),
  ElementID("Video",{0xE0},DAT_master),
  ElementID("FlagInterlaced",{0x9A},DAT_unsigned_integer),
  ElementID("StereoMode",{0x53,0xB8},DAT_unsigned_integer),
  ElementID("AlphaMode",{0x53,0xC0},DAT_unsigned_integer),
  ElementID("OldStereoMode",{0x53,0xB9},DAT_unsigned_integer),
  ElementID("PixelWidth",{0xB0},DAT_unsigned_integer),
  ElementID("PixelHeight",{0xBA},DAT_unsigned_integer),
  ElementID("PixelCropBottom",{0x54,0xAA},DAT_unsigned_integer),
  ElementID("PixelCropTop",{0x54,0xBB},DAT_unsigned_integer),
  ElementID("PixelCropLeft",{0x54,0xCC},DAT_unsigned_integer),
  ElementID("PixelCropRight",{0x54,0xDD},DAT_unsigned_integer),
  ElementID("DisplayWidth",{0x54,0xB0},DAT_unsigned_integer),
  ElementID("DisplayHeight",{0x54,0xBA},DAT_unsigned_integer),
  ElementID("DisplayUnit",{0x54,0xB2},DAT_unsigned_integer),
  ElementID("AspectRatioType",{0x54,0xB3},DAT_unsigned_integer),
  ElementID("ColourSpace",{0x2E,0xB5,0x24},DAT_binary),
  ElementID("GammaValue",{0x2F,0xB5,0x23},DAT_float),
  ElementID("FrameRate",{0x23,0x83,0xE3},DAT_float),
  ElementID("Audio",{0xE1},DAT_master),
  ElementID("SamplingFrequency",{0xB5},DAT_float),
  ElementID("OutputSamplingFrequency",{0x78,0xB5},DAT_float),
  ElementID("Channels",{0x9F},DAT_unsigned_integer),
  ElementID("ChannelPositions",{0x7D,0x7B},DAT_binary),
  ElementID("BitDepth",{0x62,0x64},DAT_unsigned_integer),
  ElementID("TrackOperation",{0xE2},DAT_master),
  ElementID("TrackCombinePlanes",{0xE3},DAT_master),
  ElementID("TrackPlane",{0xE4},DAT_master),
  ElementID("TrackPlaneUID",{0xE5},DAT_unsigned_integer),
  ElementID("TrackPlaneType",{0xE6},DAT_unsigned_integer),
  ElementID("TrackJoinBlocks",{0xE9},DAT_master),
  ElementID("TrackJoinUID",{0xED},DAT_unsigned_integer),
  ElementID("TrickTrackUID",{0xC0},DAT_unsigned_integer),
  ElementID("TrickTrackSegmentUID",{0xC1},DAT_binary),
  ElementID("TrickTrackFlag",{0xC6},DAT_unsigned_integer),
  ElementID("TrickMasterTrackUID",{0xC7},DAT_unsigned_integer),
  ElementID("TrickMasterTrackSegmentUID",{0xC4},DAT_binary),
  ElementID("ContentEncodings",{0x6D,0x80},DAT_master),
  ElementID("ContentEncoding",{0x62,0x40},DAT_master),
  ElementID("ContentEncodingOrder",{0x50,0x31},DAT_unsigned_integer),
  ElementID("ContentEncodingScope",{0x50,0x32},DAT_unsigned_integer),
  ElementID("ContentEncodingType",{0x50,0x33},DAT_unsigned_integer),
  ElementID("ContentCompression",{0x50,0x34},DAT_master),
  ElementID("ContentCompAlgo",{0x42,0x54},DAT_unsigned_integer),
  ElementID("ContentCompSettings",{0x42,0x55},DAT_binary),
  ElementID("ContentEncryption",{0x50,0x35},DAT_master),
  ElementID("ContentEncAlgo",{0x47,0xE1},DAT_unsigned_integer),
  ElementID("ContentEncKeyID",{0x47,0xE2},DAT_binary),
  ElementID("ContentSignature",{0x47,0xE3},DAT_binary),
  ElementID("ContentSigKeyID",{0x47,0xE4},DAT_binary),
  ElementID("ContentSigAlgo",{0x47,0xE5},DAT_unsigned_integer),
  ElementID("ContentSigHashAlgo",{0x47,0xE6},DAT_unsigned_integer),
  ElementID("Tags",{0x12,0x54,0xC3,0x67},DAT_master),
  ElementID("Tag",{0x73,0x73},DAT_master),
  ElementID("Targets",{0x63,0xC0},DAT_master),
  ElementID("TargetTypeValue",{0x68,0xCA},DAT_unsigned_integer),
  ElementID("TargetType",{0x63,0xCA},DAT_string),
  ElementID("TagTrackUID",{0x63,0xC5},DAT_unsigned_integer),
  ElementID("TagEditionUID",{0x63,0xC9},DAT_unsigned_integer),
  ElementID("TagChapterUID",{0x63,0xC4},DAT_unsigned_integer),
  ElementID("TagAttachmentUID",{0x63,0xC6},DAT_unsigned_integer),
  ElementID("SimpleTag",{0x67,0xC8},DAT_master),
  ElementID("TagName",{0x45,0xA3},DAT_utf8),
  ElementID("TagLanguage",{0x44,0x7A},DAT_string),
  ElementID("TagDefault",{0x44,0x84},DAT_unsigned_integer),
  ElementID("TagString",{0x44,0x87},DAT_utf8),
  ElementID("TagBinary",{0x44,0x85},DAT_binary),
  ElementID("Void"  ,{0xEC},DAT_binary),
  ElementID("CRC-32",{0xBF},DAT_binary),
  ElementID("SignatureSlot",{0x1B,0x53,0x86,0x67},DAT_master),
  ElementID("SignatureAlgo",{0x7E,0x8A},DAT_unsigned_integer),
  ElementID("SignatureHash",{0x7E,0x9A},DAT_unsigned_integer),
  ElementID("SignaturePublicKey",{0x7E,0xA5},DAT_binary),
  ElementID("Signature",{0x7E,0xB5},DAT_binary),
  ElementID("SignatureElements",{0x7E,0x5B},DAT_master),
  ElementID("SignatureElementList",{0x7E,0x7B},DAT_master),
  ElementID("SignedElement",{0x65,0x32},DAT_binary),
});





}




