#include"ebmlut_master.hpp"
#include"ebmlut_primitives.hpp"
#include"ebmlut_strings.hpp"




namespace ebmlut{




Master::
Master(const char*  path)
{
  auto  f = fopen(path,"rb");

    if(f)
    {
      fseek(f,0,SEEK_END);

      auto  size = ftell(f);

      rewind(f);

      read(f,size);

      fclose(f);
    }
}


Master::
Master(const ElementID*  _id, FILE*  f, size_t  f_data_size):
Element(_id)
{
  read(f,f_data_size);
}


Master::
~Master()
{
    for(auto  ptr: children)
    {
      delete ptr;
    }
}




void
Master::
read(FILE*  f, size_t  f_data_size)
{
    if(!f)
    {
      return;
    }


  VInt         id_vint;
  VInt  data_size_vint;

    while(f_data_size)
    {
             id_vint.read(f);
      data_size_vint.read(f);

      const auto  child_value     =                id_vint.get_value();
      const auto  child_data_size = data_size_vint.get_decoded_value();

      const size_t  element_size = (id_vint.size+data_size_vint.size+child_data_size);

      auto  child_id = id_tree[child_value];

        if(child_id)
        {
            switch(child_id->data_type)
            {
              case(DAT_unsigned_integer):
              case(DAT_signed_integer):
              case(DAT_date):
              case(DAT_float):
                children.emplace_back(new Primitives(child_id,f,child_data_size));
                break;
              case(DAT_string):
              case(DAT_utf8  ):
              case(DAT_binary):
                children.emplace_back(new Strings(child_id,f,child_data_size));
                break;
              case(DAT_master):
                children.emplace_back(new Master(child_id,f,child_data_size));
                break;
              default:
                report;
            }
        }

      else
        {
          printf("unknown element fonud in <%s>\n",id->fullname.data());
          printf("ignore(%d bytes).",(int)child_data_size);
          id_vint.print();

          fseek(f,child_data_size,SEEK_CUR);
        }


        if(f_data_size < element_size)
        {
          report;
          return;
        }


      f_data_size -= element_size;
    }
}




size_t
Master::
get_number() const
{
  return children.size();
}


Element*
Master::operator[](int  i) const
{
  return children[i];
}




size_t
Master::
get_data_size() const
{
  size_t  size = 0;

    for(auto  ptr: children)
    {
      size += ptr->get_size();
    }


  return size;
}


void
Master::
print() const
{
  Element::print();

  printf("\n");

  const ElementID*  last_id = nullptr;

  int  n = 0;

    for(auto  ptr: children)
    {
      auto  child_id = ptr->get_id();

        if(child_id && (child_id->data_type == DAT_binary))
        {
            if(!n)
            {
              last_id = child_id;
            }


          n += 1;
        }

      else
        {
            if(n)
            {
              last_id->print();

              printf("...x%d\n",n);

              n = 0;
            }


          ptr->print();
          printf("\n");
        }
    }
}




}





